#
# Copyright (C) 2018-2019 by frePPLe bv
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
# General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

#
# STAGE 1: Compile and build the application
#

FROM opensuse/leap:15.1 as builder

RUN zypper refresh && \
  zypper --non-interactive update && \
  zypper --non-interactive install --force-resolution --replacefiles \
    libxerces-c-3_1 httpd python3 python3-pip python3-psycopg2 \
    libxerces-c-devel openssl make automake autoconf python3-devel \
    gcc-c++ rpm-build libpq5 postgresql-devel postgresql \
    libtool git openssl-devel && \
  pip3 install sphinx && \
  zypper clean

RUN useradd builder -u 1000 -m -G users && \
  echo "builder ALL=(ALL:ALL) NOPASSWD:ALL" >> /etc/sudoers && \
  echo "%_topdir    /home/builder/rpm" >> /home/builder/.rpmmacros && \
  mkdir /home/builder/rpm && \
  mkdir -p /home/builder/rpm/{BUILD,RPMS,SOURCES,SPECS,SRPMS} && \
  chown -R builder /home/builder

# OPTION 1: BUILDING FROM LOCAL DISTRIBUTION:
ADD requirements.txt .
RUN pip3 install -r requirements.txt

# An alternative to the copy is to clone from git:
# RUN git clone https://github.com/frepple/frepple.git frepple
USER builder
COPY --chown=1000 frepple.spec /home/builder/rpm/SPECS/
COPY --chown=1000 *.tar.gz /home/builder/rpm/SOURCES/
RUN rpmbuild -ba /home/builder/rpm/SPECS/frepple.spec

FROM scratch as package
COPY --from=builder frepple-*/build/*.rpm .

#
# STAGE 2: Build the deployment container
#

FROM opensuse/leap:15.1

RUN zypper refresh && \
  zypper --non-interactive update && \
  zypper --non-interactive install --force-resolution --replacefiles \
    libxerces-c-3_1 openssl httpd apache2-mod_wsgi-python3 python3 \
    python3-pip libpq5 python3-psycopg2 postgresql && \
  zypper clean

COPY --from=builder /requirements.txt .
COPY --from=builder /home/builder/rpm/RPMS/x86_64/frepple-*-1.x86_64.rpm ./

RUN rpm -i frepple*.rpm && \
  pip3 install -r requirements.txt && \
  a2enmod proxy && \
  a2enmod proxy_wstunnel && \
  rm requirements.txt *.rpm

EXPOSE 80
EXPOSE 443

VOLUME ["/var/log/frepple", "/etc/frepple", "/var/log/apache2", "/etc/apache2"]

# Update djangosettings
# TODO update random secret key
RUN sed -i 's/"HOST": ""/"HOST": "frepple-postgres"/g' /etc/frepple/djangosettings.py

CMD frepplectl migrate && \
  rcapache2 start && \
  tail -f /var/log/apache2/*log


